# pylint: skip-file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: course_lesson/grpc/course_lesson.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&course_lesson/grpc/course_lesson.proto\x12\x14\x63onfig.course_lesson\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto"\xa7\x01\n\x11\x41\x64\x64\x43ommentRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x17\n\x0fuser_identifier\x18\x04 \x01(\t\x12\x17\n\nowner_slug\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug"Z\n\x12\x41\x64\x64\x43ommentResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"X\n\x10\x43\x61tegoryResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct";\n\x17\x43\x61tegoryRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"\x94\x01\n\x11\x43onsultantRequest\x12\x11\n\tfull_name\x18\x02 \x01(\t\x12\x14\n\x0cphone_number\x18\x03 \x01(\t\x12\x16\n\titem_type\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x0fitem_identifier\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_item_typeB\x12\n\x10_item_identifier"Z\n\x12\x43onsultantResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"\x9b\x01\n\x11\x43ourseListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x16\n\titem_type\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x0cinvoker_unit\x18\x05 \x01(\tB\x0b\n\t_order_byB\x0c\n\n_item_type"V\n\x0e\x43ourseResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"A\n\x1d\x43ourseRetrieveCommentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t">\n\x1a\x43ourseRetrieveRatesRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"9\n\x15\x43ourseRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"W\n\x0fGeneralResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"B\n\x16GeneralRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x14\n\x0cinvoker_unit\x18\x02 \x01(\t"u\n\x11LessonListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x14\n\x0cinvoker_unit\x18\x04 \x01(\tB\x0b\n\t_order_by"V\n\x0eLessonResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"A\n\x1dLessonRetrieveCommentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"9\n\x15LessonRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"*\n\rMasterRequest\x12\x19\n\x11master_identifier\x18\x01 \x01(\t"V\n\x0eMasterResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"v\n\x12PackageListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x14\n\x0cinvoker_unit\x18\x04 \x01(\tB\x0b\n\t_order_by"W\n\x0fPackageResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct":\n\x16PackageRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t"\x90\x01\n\x0bRateRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\x0fuser_identifier\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x02\x12\x17\n\nowner_slug\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug"T\n\x0cRateResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"Y\n\x11TopBannerResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"p\n\x12TriggerLikeRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nowner_slug\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug"[\n\x13TriggerLikeResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct2\xcf\x01\n\x12\x43\x61tegoryController\x12T\n\x10HierarchicalList\x12\x16.google.protobuf.Empty\x1a&.config.course_lesson.CategoryResponse"\x00\x12\x63\n\x08Retrieve\x12-.config.course_lesson.CategoryRetrieveRequest\x1a&.config.course_lesson.CategoryResponse"\x00\x32u\n\x14\x43onsultantController\x12]\n\x06\x43reate\x12\'.config.course_lesson.ConsultantRequest\x1a(.config.course_lesson.ConsultantResponse"\x00\x32\xfc\x06\n\x10\x43ourseController\x12^\n\x07\x43omment\x12\'.config.course_lesson.AddCommentRequest\x1a(.config.course_lesson.AddCommentResponse"\x00\x12\x61\n\x12\x46\x65tchMasterCourses\x12#.config.course_lesson.MasterRequest\x1a$.config.course_lesson.MasterResponse"\x00\x12]\n\x04Like\x12(.config.course_lesson.TriggerLikeRequest\x1a).config.course_lesson.TriggerLikeResponse"\x00\x12W\n\x04List\x12\'.config.course_lesson.CourseListRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12O\n\x04Rate\x12!.config.course_lesson.RateRequest\x1a".config.course_lesson.RateResponse"\x00\x12_\n\x08Retrieve\x12+.config.course_lesson.CourseRetrieveRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12o\n\x10RetrieveComments\x12\x33.config.course_lesson.CourseRetrieveCommentsRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12i\n\rRetrieveRates\x12\x30.config.course_lesson.CourseRetrieveRatesRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12_\n\x06UnLike\x12(.config.course_lesson.TriggerLikeRequest\x1a).config.course_lesson.TriggerLikeResponse"\x00\x32v\n\x11GeneralController\x12\x61\n\x08Retrieve\x12,.config.course_lesson.GeneralRetrieveRequest\x1a%.config.course_lesson.GeneralResponse"\x00\x32\x9d\x03\n\x10LessonController\x12^\n\x07\x43omment\x12\'.config.course_lesson.AddCommentRequest\x1a(.config.course_lesson.AddCommentResponse"\x00\x12W\n\x04List\x12\'.config.course_lesson.LessonListRequest\x1a$.config.course_lesson.LessonResponse"\x00\x12_\n\x08Retrieve\x12+.config.course_lesson.LessonRetrieveRequest\x1a$.config.course_lesson.LessonResponse"\x00\x12o\n\x10RetrieveComments\x12\x33.config.course_lesson.LessonRetrieveCommentsRequest\x1a$.config.course_lesson.LessonResponse"\x00\x32\x82\x07\n\x16MasterCourseController\x12^\n\x07\x43omment\x12\'.config.course_lesson.AddCommentRequest\x1a(.config.course_lesson.AddCommentResponse"\x00\x12\x61\n\x12\x46\x65tchMasterCourses\x12#.config.course_lesson.MasterRequest\x1a$.config.course_lesson.MasterResponse"\x00\x12]\n\x04Like\x12(.config.course_lesson.TriggerLikeRequest\x1a).config.course_lesson.TriggerLikeResponse"\x00\x12W\n\x04List\x12\'.config.course_lesson.CourseListRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12O\n\x04Rate\x12!.config.course_lesson.RateRequest\x1a".config.course_lesson.RateResponse"\x00\x12_\n\x08Retrieve\x12+.config.course_lesson.CourseRetrieveRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12o\n\x10RetrieveComments\x12\x33.config.course_lesson.CourseRetrieveCommentsRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12i\n\rRetrieveRates\x12\x30.config.course_lesson.CourseRetrieveRatesRequest\x1a$.config.course_lesson.CourseResponse"\x00\x12_\n\x06UnLike\x12(.config.course_lesson.TriggerLikeRequest\x1a).config.course_lesson.TriggerLikeResponse"\x00\x32\xd1\x01\n\x11PackageController\x12Y\n\x04List\x12(.config.course_lesson.PackageListRequest\x1a%.config.course_lesson.PackageResponse"\x00\x12\x61\n\x08Retrieve\x12,.config.course_lesson.PackageRetrieveRequest\x1a%.config.course_lesson.PackageResponse"\x00\x32k\n\x13TopBannerController\x12T\n\x0fRetrieveCurrent\x12\x16.google.protobuf.Empty\x1a\'.config.course_lesson.TopBannerResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "course_lesson.grpc.course_lesson_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ADDCOMMENTREQUEST"]._serialized_start = 124
    _globals["_ADDCOMMENTREQUEST"]._serialized_end = 291
    _globals["_ADDCOMMENTRESPONSE"]._serialized_start = 293
    _globals["_ADDCOMMENTRESPONSE"]._serialized_end = 383
    _globals["_CATEGORYRESPONSE"]._serialized_start = 385
    _globals["_CATEGORYRESPONSE"]._serialized_end = 473
    _globals["_CATEGORYRETRIEVEREQUEST"]._serialized_start = 475
    _globals["_CATEGORYRETRIEVEREQUEST"]._serialized_end = 534
    _globals["_CONSULTANTREQUEST"]._serialized_start = 537
    _globals["_CONSULTANTREQUEST"]._serialized_end = 685
    _globals["_CONSULTANTRESPONSE"]._serialized_start = 687
    _globals["_CONSULTANTRESPONSE"]._serialized_end = 777
    _globals["_COURSELISTREQUEST"]._serialized_start = 780
    _globals["_COURSELISTREQUEST"]._serialized_end = 935
    _globals["_COURSERESPONSE"]._serialized_start = 937
    _globals["_COURSERESPONSE"]._serialized_end = 1023
    _globals["_COURSERETRIEVECOMMENTSREQUEST"]._serialized_start = 1025
    _globals["_COURSERETRIEVECOMMENTSREQUEST"]._serialized_end = 1090
    _globals["_COURSERETRIEVERATESREQUEST"]._serialized_start = 1092
    _globals["_COURSERETRIEVERATESREQUEST"]._serialized_end = 1154
    _globals["_COURSERETRIEVEREQUEST"]._serialized_start = 1156
    _globals["_COURSERETRIEVEREQUEST"]._serialized_end = 1213
    _globals["_GENERALRESPONSE"]._serialized_start = 1215
    _globals["_GENERALRESPONSE"]._serialized_end = 1302
    _globals["_GENERALRETRIEVEREQUEST"]._serialized_start = 1304
    _globals["_GENERALRETRIEVEREQUEST"]._serialized_end = 1370
    _globals["_LESSONLISTREQUEST"]._serialized_start = 1372
    _globals["_LESSONLISTREQUEST"]._serialized_end = 1489
    _globals["_LESSONRESPONSE"]._serialized_start = 1491
    _globals["_LESSONRESPONSE"]._serialized_end = 1577
    _globals["_LESSONRETRIEVECOMMENTSREQUEST"]._serialized_start = 1579
    _globals["_LESSONRETRIEVECOMMENTSREQUEST"]._serialized_end = 1644
    _globals["_LESSONRETRIEVEREQUEST"]._serialized_start = 1646
    _globals["_LESSONRETRIEVEREQUEST"]._serialized_end = 1703
    _globals["_MASTERREQUEST"]._serialized_start = 1705
    _globals["_MASTERREQUEST"]._serialized_end = 1747
    _globals["_MASTERRESPONSE"]._serialized_start = 1749
    _globals["_MASTERRESPONSE"]._serialized_end = 1835
    _globals["_PACKAGELISTREQUEST"]._serialized_start = 1837
    _globals["_PACKAGELISTREQUEST"]._serialized_end = 1955
    _globals["_PACKAGERESPONSE"]._serialized_start = 1957
    _globals["_PACKAGERESPONSE"]._serialized_end = 2044
    _globals["_PACKAGERETRIEVEREQUEST"]._serialized_start = 2046
    _globals["_PACKAGERETRIEVEREQUEST"]._serialized_end = 2104
    _globals["_RATEREQUEST"]._serialized_start = 2107
    _globals["_RATEREQUEST"]._serialized_end = 2251
    _globals["_RATERESPONSE"]._serialized_start = 2253
    _globals["_RATERESPONSE"]._serialized_end = 2337
    _globals["_TOPBANNERRESPONSE"]._serialized_start = 2339
    _globals["_TOPBANNERRESPONSE"]._serialized_end = 2428
    _globals["_TRIGGERLIKEREQUEST"]._serialized_start = 2430
    _globals["_TRIGGERLIKEREQUEST"]._serialized_end = 2542
    _globals["_TRIGGERLIKERESPONSE"]._serialized_start = 2544
    _globals["_TRIGGERLIKERESPONSE"]._serialized_end = 2635
    _globals["_CATEGORYCONTROLLER"]._serialized_start = 2638
    _globals["_CATEGORYCONTROLLER"]._serialized_end = 2845
    _globals["_CONSULTANTCONTROLLER"]._serialized_start = 2847
    _globals["_CONSULTANTCONTROLLER"]._serialized_end = 2964
    _globals["_COURSECONTROLLER"]._serialized_start = 2967
    _globals["_COURSECONTROLLER"]._serialized_end = 3859
    _globals["_GENERALCONTROLLER"]._serialized_start = 3861
    _globals["_GENERALCONTROLLER"]._serialized_end = 3979
    _globals["_LESSONCONTROLLER"]._serialized_start = 3982
    _globals["_LESSONCONTROLLER"]._serialized_end = 4395
    _globals["_MASTERCOURSECONTROLLER"]._serialized_start = 4398
    _globals["_MASTERCOURSECONTROLLER"]._serialized_end = 5296
    _globals["_PACKAGECONTROLLER"]._serialized_start = 5299
    _globals["_PACKAGECONTROLLER"]._serialized_end = 5508
    _globals["_TOPBANNERCONTROLLER"]._serialized_start = 5510
    _globals["_TOPBANNERCONTROLLER"]._serialized_end = 5617
# @@protoc_insertion_point(module_scope)
