from setuptools import setup

with open("README.md", "r") as f:
    long_description = f.read()


setup(
    name="dmcl",
    version="2.15.0",
    author="Ellnamin",
    author_email="ellnamin.business@gmail.com",
    description="Course Lesson Service for Darsman Academy",
    long_description=long_description,
    packages=["dmcl", "dmcl/grpc_lib"],
    install_requires=[
        "grpcio==1.62.1",
        "grpcio-tools==1.62.1",
        "protobuf==4.25.3",
        "setuptools==69.1.1",
        "annotated-types==0.6.0",
        "pydantic==2.7.0",
        "pydantic_core==2.18.1",
    ],
    setup_requires=["wheel", "setuptools"],
)
